==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/TrafficPolicyFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import javax.validation.Valid;
import java.util.Collection;
import java.lang.Object;

public interface TrafficPolicyFluent<A extends TrafficPolicyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConnectionPool instead.
 * @return The buildable object.
 */
@Deprecated public ConnectionPoolSettings getConnectionPool();
    public ConnectionPoolSettings buildConnectionPool();
    public A withConnectionPool(ConnectionPoolSettings connectionPool);
    public Boolean hasConnectionPool();
    public TrafficPolicyFluent.ConnectionPoolNested<A> withNewConnectionPool();
    public TrafficPolicyFluent.ConnectionPoolNested<A> withNewConnectionPoolLike(ConnectionPoolSettings item);
    public TrafficPolicyFluent.ConnectionPoolNested<A> editConnectionPool();
    public TrafficPolicyFluent.ConnectionPoolNested<A> editOrNewConnectionPool();
    public TrafficPolicyFluent.ConnectionPoolNested<A> editOrNewConnectionPoolLike(ConnectionPoolSettings item);
    
/**
 * This method has been deprecated, please use method buildLoadBalancer instead.
 * @return The buildable object.
 */
@Deprecated public LoadBalancerSettings getLoadBalancer();
    public LoadBalancerSettings buildLoadBalancer();
    public A withLoadBalancer(LoadBalancerSettings loadBalancer);
    public Boolean hasLoadBalancer();
    public TrafficPolicyFluent.LoadBalancerNested<A> withNewLoadBalancer();
    public TrafficPolicyFluent.LoadBalancerNested<A> withNewLoadBalancerLike(LoadBalancerSettings item);
    public TrafficPolicyFluent.LoadBalancerNested<A> editLoadBalancer();
    public TrafficPolicyFluent.LoadBalancerNested<A> editOrNewLoadBalancer();
    public TrafficPolicyFluent.LoadBalancerNested<A> editOrNewLoadBalancerLike(LoadBalancerSettings item);
    
/**
 * This method has been deprecated, please use method buildOutlierDetection instead.
 * @return The buildable object.
 */
@Deprecated public OutlierDetection getOutlierDetection();
    public OutlierDetection buildOutlierDetection();
    public A withOutlierDetection(OutlierDetection outlierDetection);
    public Boolean hasOutlierDetection();
    public TrafficPolicyFluent.OutlierDetectionNested<A> withNewOutlierDetection();
    public TrafficPolicyFluent.OutlierDetectionNested<A> withNewOutlierDetectionLike(OutlierDetection item);
    public TrafficPolicyFluent.OutlierDetectionNested<A> editOutlierDetection();
    public TrafficPolicyFluent.OutlierDetectionNested<A> editOrNewOutlierDetection();
    public TrafficPolicyFluent.OutlierDetectionNested<A> editOrNewOutlierDetectionLike(OutlierDetection item);
    public A addToPortLevelSettings(int index,PortTrafficPolicy item);
    public A setToPortLevelSettings(int index,PortTrafficPolicy item);
    public A addToPortLevelSettings(PortTrafficPolicy... items);
    public A addAllToPortLevelSettings(Collection<PortTrafficPolicy> items);
    public A removeFromPortLevelSettings(PortTrafficPolicy... items);
    public A removeAllFromPortLevelSettings(Collection<PortTrafficPolicy> items);
    
/**
 * This method has been deprecated, please use method buildPortLevelSettings instead.
 * @return The buildable object.
 */
@Deprecated public List<PortTrafficPolicy> getPortLevelSettings();
    public List<PortTrafficPolicy> buildPortLevelSettings();
    public PortTrafficPolicy buildPortLevelSetting(int index);
    public PortTrafficPolicy buildFirstPortLevelSetting();
    public PortTrafficPolicy buildLastPortLevelSetting();
    public PortTrafficPolicy buildMatchingPortLevelSetting(io.fabric8.kubernetes.api.builder.Predicate<PortTrafficPolicyBuilder> predicate);
    public A withPortLevelSettings(List<PortTrafficPolicy> portLevelSettings);
    public A withPortLevelSettings(PortTrafficPolicy... portLevelSettings);
    public Boolean hasPortLevelSettings();
    public TrafficPolicyFluent.PortLevelSettingsNested<A> addNewPortLevelSetting();
    public TrafficPolicyFluent.PortLevelSettingsNested<A> addNewPortLevelSettingLike(PortTrafficPolicy item);
    public TrafficPolicyFluent.PortLevelSettingsNested<A> setNewPortLevelSettingLike(int index,PortTrafficPolicy item);
    public TrafficPolicyFluent.PortLevelSettingsNested<A> editPortLevelSetting(int index);
    public TrafficPolicyFluent.PortLevelSettingsNested<A> editFirstPortLevelSetting();
    public TrafficPolicyFluent.PortLevelSettingsNested<A> editLastPortLevelSetting();
    public TrafficPolicyFluent.PortLevelSettingsNested<A> editMatchingPortLevelSetting(io.fabric8.kubernetes.api.builder.Predicate<PortTrafficPolicyBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public TLSSettings getTls();
    public TLSSettings buildTls();
    public A withTls(TLSSettings tls);
    public Boolean hasTls();
    public TrafficPolicyFluent.TlsNested<A> withNewTls();
    public TrafficPolicyFluent.TlsNested<A> withNewTlsLike(TLSSettings item);
    public TrafficPolicyFluent.TlsNested<A> editTls();
    public TrafficPolicyFluent.TlsNested<A> editOrNewTls();
    public TrafficPolicyFluent.TlsNested<A> editOrNewTlsLike(TLSSettings item);

    public interface ConnectionPoolNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConnectionPoolSettingsFluent<TrafficPolicyFluent.ConnectionPoolNested<N>>{

        
    public N and();    public N endConnectionPool();
}
    public interface LoadBalancerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LoadBalancerSettingsFluent<TrafficPolicyFluent.LoadBalancerNested<N>>{

        
    public N and();    public N endLoadBalancer();
}
    public interface OutlierDetectionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OutlierDetectionFluent<TrafficPolicyFluent.OutlierDetectionNested<N>>{

        
    public N and();    public N endOutlierDetection();
}
    public interface PortLevelSettingsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PortTrafficPolicyFluent<TrafficPolicyFluent.PortLevelSettingsNested<N>>{

        
    public N and();    public N endPortLevelSetting();
}
    public interface TlsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSSettingsFluent<TrafficPolicyFluent.TlsNested<N>>{

        
    public N and();    public N endTls();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/TrafficPolicyFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;

public interface TrafficPolicyFluent<A extends TrafficPolicyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConnectionPool instead.
 * @return The buildable object.
 */
@Deprecated public ConnectionPoolSettings getConnectionPool();
    public ConnectionPoolSettings buildConnectionPool();
    public A withConnectionPool(ConnectionPoolSettings connectionPool);
    public Boolean hasConnectionPool();
    public TrafficPolicyFluent.ConnectionPoolNested<A> withNewConnectionPool();
    public TrafficPolicyFluent.ConnectionPoolNested<A> withNewConnectionPoolLike(ConnectionPoolSettings item);
    public TrafficPolicyFluent.ConnectionPoolNested<A> editConnectionPool();
    public TrafficPolicyFluent.ConnectionPoolNested<A> editOrNewConnectionPool();
    public TrafficPolicyFluent.ConnectionPoolNested<A> editOrNewConnectionPoolLike(ConnectionPoolSettings item);
    
/**
 * This method has been deprecated, please use method buildLoadBalancer instead.
 * @return The buildable object.
 */
@Deprecated public LoadBalancerSettings getLoadBalancer();
    public LoadBalancerSettings buildLoadBalancer();
    public A withLoadBalancer(LoadBalancerSettings loadBalancer);
    public Boolean hasLoadBalancer();
    public TrafficPolicyFluent.LoadBalancerNested<A> withNewLoadBalancer();
    public TrafficPolicyFluent.LoadBalancerNested<A> withNewLoadBalancerLike(LoadBalancerSettings item);
    public TrafficPolicyFluent.LoadBalancerNested<A> editLoadBalancer();
    public TrafficPolicyFluent.LoadBalancerNested<A> editOrNewLoadBalancer();
    public TrafficPolicyFluent.LoadBalancerNested<A> editOrNewLoadBalancerLike(LoadBalancerSettings item);
    
/**
 * This method has been deprecated, please use method buildOutlierDetection instead.
 * @return The buildable object.
 */
@Deprecated public OutlierDetection getOutlierDetection();
    public OutlierDetection buildOutlierDetection();
    public A withOutlierDetection(OutlierDetection outlierDetection);
    public Boolean hasOutlierDetection();
    public TrafficPolicyFluent.OutlierDetectionNested<A> withNewOutlierDetection();
    public TrafficPolicyFluent.OutlierDetectionNested<A> withNewOutlierDetectionLike(OutlierDetection item);
    public TrafficPolicyFluent.OutlierDetectionNested<A> editOutlierDetection();
    public TrafficPolicyFluent.OutlierDetectionNested<A> editOrNewOutlierDetection();
    public TrafficPolicyFluent.OutlierDetectionNested<A> editOrNewOutlierDetectionLike(OutlierDetection item);
    public A addToPortLevelSettings(int index,PortTrafficPolicy item);
    public A setToPortLevelSettings(int index,PortTrafficPolicy item);
    public A addToPortLevelSettings(PortTrafficPolicy... items);
    public A addAllToPortLevelSettings(Collection<PortTrafficPolicy> items);
    public A removeFromPortLevelSettings(PortTrafficPolicy... items);
    public A removeAllFromPortLevelSettings(Collection<PortTrafficPolicy> items);
    public A removeMatchingFromPortLevelSettings(io.fabric8.kubernetes.api.builder.Predicate<PortTrafficPolicyBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildPortLevelSettings instead.
 * @return The buildable object.
 */
@Deprecated public List<PortTrafficPolicy> getPortLevelSettings();
    public List<PortTrafficPolicy> buildPortLevelSettings();
    public PortTrafficPolicy buildPortLevelSetting(int index);
    public PortTrafficPolicy buildFirstPortLevelSetting();
    public PortTrafficPolicy buildLastPortLevelSetting();
    public PortTrafficPolicy buildMatchingPortLevelSetting(io.fabric8.kubernetes.api.builder.Predicate<PortTrafficPolicyBuilder> predicate);
    public Boolean hasMatchingPortLevelSetting(io.fabric8.kubernetes.api.builder.Predicate<PortTrafficPolicyBuilder> predicate);
    public A withPortLevelSettings(List<PortTrafficPolicy> portLevelSettings);
    public A withPortLevelSettings(PortTrafficPolicy... portLevelSettings);
    public Boolean hasPortLevelSettings();
    public TrafficPolicyFluent.PortLevelSettingsNested<A> addNewPortLevelSetting();
    public TrafficPolicyFluent.PortLevelSettingsNested<A> addNewPortLevelSettingLike(PortTrafficPolicy item);
    public TrafficPolicyFluent.PortLevelSettingsNested<A> setNewPortLevelSettingLike(int index,PortTrafficPolicy item);
    public TrafficPolicyFluent.PortLevelSettingsNested<A> editPortLevelSetting(int index);
    public TrafficPolicyFluent.PortLevelSettingsNested<A> editFirstPortLevelSetting();
    public TrafficPolicyFluent.PortLevelSettingsNested<A> editLastPortLevelSetting();
    public TrafficPolicyFluent.PortLevelSettingsNested<A> editMatchingPortLevelSetting(io.fabric8.kubernetes.api.builder.Predicate<PortTrafficPolicyBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public TLSSettings getTls();
    public TLSSettings buildTls();
    public A withTls(TLSSettings tls);
    public Boolean hasTls();
    public TrafficPolicyFluent.TlsNested<A> withNewTls();
    public TrafficPolicyFluent.TlsNested<A> withNewTlsLike(TLSSettings item);
    public TrafficPolicyFluent.TlsNested<A> editTls();
    public TrafficPolicyFluent.TlsNested<A> editOrNewTls();
    public TrafficPolicyFluent.TlsNested<A> editOrNewTlsLike(TLSSettings item);

    public interface ConnectionPoolNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConnectionPoolSettingsFluent<TrafficPolicyFluent.ConnectionPoolNested<N>>{

        
    public N and();    public N endConnectionPool();
}
    public interface LoadBalancerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LoadBalancerSettingsFluent<TrafficPolicyFluent.LoadBalancerNested<N>>{

        
    public N and();    public N endLoadBalancer();
}
    public interface OutlierDetectionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OutlierDetectionFluent<TrafficPolicyFluent.OutlierDetectionNested<N>>{

        
    public N and();    public N endOutlierDetection();
}
    public interface PortLevelSettingsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PortTrafficPolicyFluent<TrafficPolicyFluent.PortLevelSettingsNested<N>>{

        
    public N and();    public N endPortLevelSetting();
}
    public interface TlsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSSettingsFluent<TrafficPolicyFluent.TlsNested<N>>{

        
    public N and();    public N endTls();
}


}
